package console

import (
	"bufio"
	"context"
	"doc-service/domain/entity/serversitemicros/docserverproject"
	service "doc-service/domain/repository"
	"doc-service/infra/db"
	"fmt"
	"github.com/nacos-group/nacos-sdk-go/v2/common/logger"
	"gitlab.galaxy-immi.com/Backend-group/go-com/third/log"
	"os"
	"strings"
	"time"
)

// 获取转换进度
func GetConvert() {
	fmt.Println("开始获取进度...")
	ctx := context.Background()
	// 启动一个协程来执行定时任务
	tickerNum := time.NewTicker(15 * time.Second)
	defer tickerNum.Stop()

	go func() {
		for {
			select {
			case <-tickerNum.C:
				i := getConvertDoData(ctx)
				if i == 0 {
					fmt.Println("没有需要获取的文件数据: " + time.Now().Format("2006-01-02 15:04:05"))
				}
			}
		}
	}()

	// 监听命令行输入
	readerGet := bufio.NewReader(os.Stdin)
	for {
		text, _ := readerGet.ReadString('\n')
		text = strings.TrimSpace(text)

		if text == "exit" {
			fmt.Println("Exiting process...")
			os.Exit(0)
		}
	}
}

func getConvertDoData(ctx context.Context) int8 {
	list, err := db.GetServerSiteMicrosDB().DocServerProject.Query().Where(
		docserverproject.StatusEQ(1),
	).All(ctx)

	if err != nil {
		return 0
	}

	if len(list) <= 0 {
		return 0
	}

	for _, items := range list {
		res := GetProjectInfo(ctx, items.ID)
		if res > 0 {
			_, errUpdateSt := db.GetServerSiteMicrosDB().DocServerProject.UpdateOneID(items.ID).SetStatus(2).Save(ctx)
			if errUpdateSt != nil {
				log.Info("修改获取的文件进度状态失败" + errUpdateSt.Error())
				continue
			}
		}
	}

	return 0
}

func GetProjectInfo(c context.Context, projectId int32) int8 {
	projectInfo, infoErr := db.GetServerSiteMicrosDB().DocServerProject.Get(c, projectId)
	if infoErr != nil {
		return 0
	}
	request := &service.GetTaskRequest{}
	request.ProjectId = projectId
	request.RequestDefinition = true
	request.ProjectName = projectInfo.ProjectName
	request.TaskId = projectInfo.TaskID
	//task_type和原始有区别，需要使用返回的task_id的首个元素
	splitted := strings.Split(projectInfo.TaskID, "-")
	request.TaskType = splitted[0]
	result, errs := service.NewConversion().GetTaskProject(*request)
	if errs != nil || *result.StatusCode != 200 || *result.Body.Status != "Succeeded" {
		logger.Info(result)
		logger.Error("错误信息" + errs.Error())
		return 0
	}
	createGetProject(c, projectId, *result.Body.Status)

	return 1
}

func createGetProject(c context.Context, projectId int32, aliRes string) {
	var statusData int8
	if aliRes != "Succeeded" {
		statusData = 1
	} else {
		statusData = 2
	}
	_, _ = db.GetServerSiteMicrosDB().DocServerGetProject.Create().
		SetCreatedAt(time.Now()).
		SetUpdatedAt(time.Now()).
		SetStatus(statusData).
		SetCurrNum(1).
		SetAliResult(aliRes).
		SetServerProjectID(projectId).
		Save(c)
}
